#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# defaults.
from fil3s.classes.config import version
from fil3s.classes.defaults import Files,Formats,gfp,gdate

# default file objects.
File = Files.File
Script = Files.Script
Directory = Files.Directory
Zip = Files.Zip
Image = Files.Image
Bytes = Files.Bytes
Dictionary = Files.Dictionary
Array = Files.Array

# default format objects.
FilePath = Formats.FilePath 
String = Formats.String 
Boolean = Formats.Boolean 
Integer = Formats.Integer 
Date = Formats.Date